@@ -11,7 +11,7 @@ use routines;
 use Data::Object::Class;
 use Data::Object::ClassHas;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # ATTRIBUTES
 
@@ -43,6 +43,10 @@ method drop() {
   return $self;
 }
 
+method load() {
+  return $self->nano->find($self->id);
+}
+
 method save() {
   my $serial = $self->serialize;
   my $domain = $self->nano->domain($self->id);
@@ -148,6 +152,26 @@ The drop method removes the prior persisted object data.
 
 =cut
 
+=head2 load
+
+  load() : Object
+
+The load method reloads and returns an object from source.
+
+=over 4
+
+=item load example #1
+
+  # given: synopsis
+
+  $node->save;
+
+  $node = $node->load;
+
+=back
+
+=cut
+
 =head2 save
 
   save() : Str
